Package: PRA
Type: Package
Title: Project Risk Analysis
Version: 0.6.0
Authors@R: person("Paul", "Govan", email = "paul.govan2@gmail.com", role = c("aut", "cre", "cph"), comment = c(ORCID = "0000-0002-1821-8492"))
Description: Data analysis for Project Risk Management via the Second Moment Method, 
  Monte Carlo Simulation, Contingency Analysis, Sensitivity Analysis, Earned Value Management, 
  Learning Curves, Bayesian Methods, and more.
Depends: R (>= 4.1.0)
Imports: mc2d, minpack.lm, stats
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
URL: https://paulgovan.github.io/PRA/, https://github.com/paulgovan/PRA
BugReports: https://github.com/paulgovan/PRA/issues
Suggests: base64enc, corrplot, devtools, ellmer, ggplot2, igraph,
        jsonlite, knitr, networkD3, remotes, rmarkdown, scales,
        mcptools, testthat (>= 3.0.0), withr
Config/testthat/edition: 3
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-08-25 23:30:26 UTC; paulgovan
Author: Paul Govan [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-1821-8492>)
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-28 14:40:17 UTC
Built: R 4.5.2; ; 2026-08-28 18:02:21 UTC; unix
