% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tools.R
\name{html_result_table}
\alias{html_result_table}
\title{Build an HTML table from name-value pairs}
\usage{
html_result_table(...)
}
\description{
Build an HTML table from name-value pairs
}
\keyword{internal}
