% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tools.R
\name{tool_result}
\alias{tool_result}
\title{Build a ContentToolResult or fall back to plain text}
\usage{
tool_result(text, title = NULL, html = NULL)
}
\description{
Build a ContentToolResult or fall back to plain text
}
\keyword{internal}
