% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sigmoidal.R
\name{print.pra_sigmoidal_fit}
\alias{print.pra_sigmoidal_fit}
\title{Print method for Sigmoidal Model}
\usage{
\method{print}{pra_sigmoidal_fit}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"pra_sigmoidal_fit"} as returned by
\code{\link{fit_sigmoidal}}.}

\item{...}{Additional arguments (not used).}
}
\value{
No return value, called for side effects.
}
\description{
Displays the summary of the fitted sigmoidal model in a readable format.
}
\examples{
# Set up a data frame of time and completion percentage data
data <- data.frame(time = 1:10, completion = c(
  5, 15, 40, 60, 70, 75, 80, 85,
  90, 95
))

# Fit a logistic model to the data.
fit <- fit_sigmoidal(data, "time", "completion", "logistic")
# Print the model summary
print(fit)
}
