% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/evm.R
\name{vac}
\alias{vac}
\title{Variance at Completion (VAC).}
\usage{
vac(bac, eac)
}
\arguments{
\item{bac}{Budget at Completion (BAC) (total planned budget).}

\item{eac}{Estimate at Completion.}
}
\value{
The function returns the Variance at Completion (VAC).
}
\description{
Calculates the Variance at Completion (VAC), which is the difference between
the budget and the expected final cost. Positive VAC indicates under budget,
negative indicates over budget.
}
\examples{
bac <- 100000
eac <- 120482 # From EAC calculation

vac <- vac(bac, eac)
cat("Variance at Completion (VAC):", round(vac, 2), "\n")
cat("Project is expected to be", abs(round(vac, 2)), ifelse(vac < 0, "over", "under"), "budget\n")

}
\references{
Damnjanovic, Ivan, and Kenneth Reinschmidt. Data analytics for engineering and
construction project risk management. No. 172534. Cham, Switzerland: Springer, 2020.
}
\seealso{
\code{\link{eac}}, \code{\link{etc}}, \code{\link{tcpi}}
}
