% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tools.R
\name{as_r_input}
\alias{as_r_input}
\title{Coerce an input to an R object}
\usage{
as_r_input(x)
}
\description{
Accepts either a JSON string (from LLM tool calls) or a native R object
(from direct R usage). If the input is a single character string, it is
parsed as JSON. Otherwise it is returned as-is.
}
\keyword{internal}
