% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/learning.R
\name{cost_post_pdf}
\alias{cost_post_pdf}
\title{Posterior Cost Probability Density.}
\usage{
cost_post_pdf(
  num_sims,
  observed_risks,
  means_given_risks,
  sds_given_risks,
  base_cost = 0
)
}
\arguments{
\item{num_sims}{Number of random samples to draw from the posterior distribution.}

\item{observed_risks}{A vector of observed values for each risk event 'R_i' (1 if observed, 0 if not observed, NA if unobserved).}

\item{means_given_risks}{A vector of means of the normal distribution for cost 'A' given each risk event 'R_i'.}

\item{sds_given_risks}{A vector of standard deviations of the normal distribution for cost 'A' given each risk event 'R_i'.}

\item{base_cost}{The baseline cost given no risk event occurs.}
}
\value{
A numeric vector of random samples from the posterior distribution of costs.
}
\description{
This function generates random samples from the posterior distribution of the cost 'A'
given observations of multiple risk events 'R_i'. Each risk event has its own mean
and standard deviation for the cost distribution. The function also accounts for a baseline cost
when no risk event occurs.
}
\examples{
# Example with three risk events
num_sims <- 1000
observed_risks <- c(1, NA, 1)
means_given_risks <- c(10000, 15000, 5000)
sds_given_risks <- c(2000, 1000, 1000)
base_cost <- 2000
posterior_samples <- cost_post_pdf(
  num_sims = num_sims,
  observed_risks = observed_risks,
  means_given_risks = means_given_risks,
  sds_given_risks = sds_given_risks,
  base_cost = base_cost
)
hist(posterior_samples, breaks = 30, col = "skyblue", main = "Posterior Cost PDF", xlab = "Cost")
}
\references{
Damnjanovic, Ivan, and Kenneth Reinschmidt. Data analytics for engineering and
construction project risk management. No. 172534. Cham, Switzerland: Springer, 2020.
}
