% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tools.R
\name{as_numeric_input}
\alias{as_numeric_input}
\title{Coerce input to a numeric vector}
\usage{
as_numeric_input(x)
}
\description{
Parses JSON input and ensures the result is a numeric vector. Handles
cases where LLMs send string representations of numbers.
}
\keyword{internal}
